Module data_structures

Module data_structures 

Defines the data structures used by the MLSumcheck protocol.

Structs

ListOfProductsOfPolynomials
Stores a list of products of DenseMultilinearExtension that is meant to be added together.
PolynomialInfo
Stores the number of variables and max number of multiplicands of the added polynomial used by the prover. This data structures will is used as the verifier key.