Struct ark_linear_sumcheck::ml_sumcheck::protocol::prover::ProverState[][src]

pub struct ProverState<F: Field> {
    pub randomness: Vec<F>,
    pub list_of_products: Vec<(F, Vec<usize>)>,
    pub flattened_ml_extensions: Vec<DenseMultilinearExtension<F>>,
    // some fields omitted
}

Prover State

Fields

randomness: Vec<F>

sampled randomness given by the verifier

list_of_products: Vec<(F, Vec<usize>)>

Stores the list of products that is meant to be added together. Each multiplicand is represented by the index in flattened_ml_extensions

flattened_ml_extensions: Vec<DenseMultilinearExtension<F>>

Stores a list of multilinear extensions in which self.list_of_products points to