Struct ark_linear_sumcheck::ml_sumcheck::MLSumcheck [−][src]
Sumcheck for products of multilinear polynomial
Implementations
impl<F: Field> MLSumcheck<F>[src]
pub fn extract_sum(proof: &Proof<F>) -> F[src]
extract sum from the proof
pub fn prove(
polynomial: &ListOfProductsOfPolynomials<F>
) -> Result<Proof<F>, Error>[src]
polynomial: &ListOfProductsOfPolynomials<F>
) -> Result<Proof<F>, Error>
generate proof of the sum of polynomial over {0,1}^num_vars
The polynomial is represented by a list of products of polynomials along with its coefficient that is meant to be added together.
This data structure of the polynomial is a list of list of (coefficient, DenseMultilinearExtension).
- Number of products n =
polynomial.products.len(), - Number of multiplicands of ith product m_i =
polynomial.products[i].1.len(), - Coefficient of ith product c_i =
polynomial.products[i].0
The resulting polynomial is
$$\sum_{i=0}^{n}C_i\cdot\prod_{j=0}^{m_i}P_{ij}$$
pub fn verify(
polynomial_info: &PolynomialInfo,
claimed_sum: F,
proof: &Proof<F>
) -> Result<SubClaim<F>, Error>[src]
polynomial_info: &PolynomialInfo,
claimed_sum: F,
proof: &Proof<F>
) -> Result<SubClaim<F>, Error>
verify the claimed sum using the proof